import * as GraphQLPackage from "graphql";
import type { GraphQLSchema, FragmentDefinitionNode, OperationDefinitionNode, GraphQLType, DocumentNode } from "graphql";
import { Maybe } from "graphql/jsutils/Maybe";
import { OperationData } from "./codegen/codegenHelpers";
export default function capitalizeFirstLetter(string: string): string;
declare type OutEnum = {
    kind: "enum";
    description?: Maybe<string>;
    values: string[];
};
declare type OutSelection = Record<string, OutSelectionFieldValue>;
declare type OutSelectionFieldValue = {
    kind: "selection_field";
    name: string;
    isNullable: boolean;
    type: OutType;
    description?: Maybe<string>;
};
declare type OutInlineFragment = {
    kind: "inlineFragment";
    typeCondition: string;
    selections: OutSelection;
};
declare type OutObject = {
    kind: "object";
    description?: Maybe<string>;
    namedFragments: string[];
    inlineFragments: OutInlineFragment[];
    selections: OutSelection;
};
declare type OutArray = {
    kind: "array";
    description?: Maybe<string>;
    type: OutType;
};
declare type OutScalar = {
    kind: "scalar";
    description?: Maybe<string>;
    type: string;
};
declare type OutType = OutEnum | OutObject | OutArray | OutScalar;
export declare function gatherAllReferencedTypes(GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, query: OperationDefinitionNode): Array<string>;
export declare function gatherVariableDefinitions(GraphQL: typeof GraphQLPackage, definition: OperationDefinitionNode): Array<[string, string]>;
export declare function typeScriptForGraphQLType(GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, gqlType: GraphQLType): string;
export declare const guessVariableDescriptions: (GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, operationDefinition: OperationDefinitionNode, variableNames: string[]) => Record<string, {
    usageCount: number;
    descriptions?: Set<string>;
}>;
export declare function typeScriptSignatureForOperationVariables(GraphQL: typeof GraphQLPackage, variableNames: Array<string>, schema: GraphQLSchema, operationDefinition: OperationDefinitionNode): string;
export declare function listCount(GraphQL: typeof GraphQLPackage, gqlType: any): number;
export declare function typeScriptDefinitionObjectForOperation(GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, operationDefinition: OperationDefinitionNode | FragmentDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): OutObject;
export declare function typeScriptSignatureForOperation(GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, operationDefinition: OperationDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): string;
export declare function typeScriptDefinitionObjectForFragment(GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, fragmentDefinition: FragmentDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): OutObject | OutScalar;
export declare function typeScriptSignatureForFragment(GraphQL: typeof GraphQLPackage, schema: GraphQLSchema, fragmentDefinition: FragmentDefinitionNode, fragmentDefinitions: Record<string, FragmentDefinitionNode>): string;
export declare function typeScriptTypeNameForOperation(name: string): string;
/**
 * Doesn't patch e.g. fragments
 */
export declare function patchSubscriptionWebhookField({ GraphQL, schema, definition, }: {
    GraphQL: typeof GraphQLPackage;
    schema: GraphQLSchema;
    definition: OperationDefinitionNode;
}): OperationDefinitionNode;
export declare function patchSubscriptionWebhookSecretField({ GraphQL, schema, definition, }: {
    GraphQL: typeof GraphQLPackage;
    schema: GraphQLSchema;
    definition: OperationDefinitionNode;
}): OperationDefinitionNode;
export declare const formInput: (GraphQL: typeof GraphQLPackage, schema: any, def: any, path?: never[]) => string | null;
export declare const remixFormInput: (GraphQL: typeof GraphQLPackage, schema: any, def: any, path?: never[]) => string | null;
export declare const formElComponent: ({ GraphQL, operationData, schema, callFn, }: {
    GraphQL: typeof GraphQLPackage;
    operationData: OperationData;
    schema: GraphQLSchema;
    callFn: string;
}) => {
    formHelpers: string;
    formEl: string;
};
export declare const normalizeOperationsDoc: (GraphQL: typeof GraphQLPackage, operationsDoc: string) => string;
export declare const gatherHardcodedValues: (GraphQL: typeof GraphQLPackage, query: string) => [string, string | number][];
export declare const extractPersistableOperation: (GraphQL: typeof GraphQLPackage, doc: DocumentNode, operationDefinition: OperationDefinitionNode) => {
    fragmentDependencies: FragmentDefinitionNode[];
    persistableOperationString: string;
} | null;
export {};
